Demo : jPlayer as video playlist and audio playlist players

play

- previous
- play
- pause
- next
- stop
- mute
- unmute
- max volume

- full screen
- restore screen
- shuffle
- shuffle off
- repeat
- repeat off

Update Required To play the media you will need to either update your browser to a recent version or update your Flash plugin.

- previous
- play
- pause
- next
- stop
- mute
- unmute
- max volume

- shuffle
- shuffle off
- repeat
- repeat off

Update Required To play the media you will need to either update your browser to a recent version or update your Flash plugin.